@@ -1,7 +1,7 @@
 /* Enumerate biclique in bipartite graphs
  * Author: Yuping Lu
  * Created: February 2017
- * Last Update: March 2017
+ * Last Update: August 2017
  */
 
 #ifndef __BICLIQUE_H
@@ -10,10 +10,12 @@
 #include <R.h>
 #include <Rinternals.h>
 
+typedef unsigned int num_t;
+
 /* ---------------------------------------- *
  * Biclique Enumeration Functions           *
  * ---------------------------------------- */
-void biclique_enumerate(int **g_right, int **g_left, int *profile, BiGraph *G, vid_t *, int);
+void biclique_enumerate(num_t **g_right, num_t **g_left, num_t *profile, BiGraph *G, vid_t *, int);
 
 #endif
 
